@@ -11,6 +11,7 @@ from io import StringIO
 from prompt_toolkit import PromptSession
 from prompt_toolkit.auto_suggest import AutoSuggest, Suggestion
 from prompt_toolkit.completion import Completer, Completion
+from prompt_toolkit.enums import EditingMode
 from prompt_toolkit.history import FileHistory
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.key_binding.defaults import load_key_bindings
@@ -84,7 +85,7 @@ class Console(code.InteractiveConsole):
     # replaced with `prompt_toolkit.input.defaults.create_pipe_input`
     prompt_input = None
 
-    def __init__(self, project=None, extra_locals=None):
+    def __init__(self, project=None, extra_locals=None, exit_on_continue=False):
         """
         Launch the Brownie console.
 
@@ -94,6 +95,9 @@ class Console(code.InteractiveConsole):
             Active Brownie project to include in the console's local namespace.
         extra_locals: dict, optional
             Additional variables to add to the console namespace.
+        exit_on_continue: bool, optional
+            If True, the `continue` command causes the console to
+            raise a SystemExit with error message "continue".
         """
         console_settings = CONFIG.settings["console"]
 
@@ -102,6 +106,11 @@ class Console(code.InteractiveConsole):
             _dir=dir, dir=self._dir, exit=_Quitter("exit"), quit=_Quitter("quit"), _console=self
         )
 
+        self.exit_on_continue = exit_on_continue
+        if exit_on_continue:
+            # add continue to the locals so we can quickly reach it via completion hints
+            locals_dict["continue"] = True
+
         if project:
             project._update_and_register(locals_dict)
 
@@ -128,6 +137,8 @@ class Console(code.InteractiveConsole):
             kwargs["auto_suggest"] = ConsoleAutoSuggest(self, locals_dict)
         if console_settings["completions"]:
             kwargs["completer"] = ConsoleCompleter(self, locals_dict)
+        if console_settings["editing_mode"]:
+            kwargs["editing_mode"] = EditingMode(console_settings["editing_mode"].upper())
 
         self.compile_mode = "single"
         self.prompt_session = PromptSession(
@@ -215,6 +226,10 @@ class Console(code.InteractiveConsole):
         mode = self.compile_mode
         self.compile_mode = "single"
 
+        if source == "continue" and self.exit_on_continue:
+            # used to differentiate exit and continue for pytest interactive debugging
+            raise SystemExit("continue")
+
         try:
             code = self.compile(source, filename, mode)
         except (OverflowError, SyntaxError, ValueError):
