@@ -4,12 +4,13 @@
 from .account import Accounts
 from .main import connect, disconnect, gas_limit, gas_price, is_connected, show_active  # NOQA 401
 from .rpc import Rpc
-from .state import TxHistory
+from .state import Chain, TxHistory
 from .web3 import web3
 
-__all__ = ["accounts", "history", "rpc", "web3"]
+__all__ = ["accounts", "chain", "history", "rpc", "web3"]
 __console_dir__ = ["connect", "disconnect", "show_active", "is_connected", "gas_limit", "gas_price"]
 
 accounts = Accounts()
 rpc = Rpc()
 history = TxHistory()
+chain = Chain()
