@@ -373,12 +373,14 @@ class ContractContainer(_ContractBase):
         """Flatten contract and publish source on the selected explorer"""
 
         # Check required conditions for verifying
+        allowed_explorers = ["etherscan", "bscscan"]
         url = CONFIG.active_network.get("explorer")
         if url is None:
             raise ValueError("Explorer API not set for this network")
-        if "etherscan" not in url:
+        if not any(allowed_explorer in url for allowed_explorer in allowed_explorers):
             raise ValueError(
-                "Publishing source is only supported on etherscan, change the Explorer API"
+                f"Publishing source is only supported on {allowed_explorers},"
+                "change the Explorer API"
             )
 
         if os.getenv("ETHERSCAN_TOKEN"):
@@ -453,7 +455,7 @@ class ContractContainer(_ContractBase):
                 if i >= 10:
                     raise ValueError(f"API request failed with: {data['result']}")
                 elif i == 0 and not silent:
-                    print("Waiting for etherscan to process contract...")
+                    print(f"Waiting for {url} to process contract...")
                 i += 1
                 time.sleep(10)
 
@@ -775,8 +777,14 @@ class _DeployedContractBase(_ContractBase):
                 BrownieEnvironmentWarning,
             )
         elif hasattr(self, name):
-            raise AttributeError(f"Namespace collision: '{self._name}.{name}'")
-        setattr(self, name, obj)
+            warnings.warn(
+                "Namespace collision between contract function and "
+                f"brownie `Contract` class member: '{self._name}.{name}'\n"
+                f"The {name} function will not be available when interacting with {self._name}",
+                BrownieEnvironmentWarning,
+            )
+        else:
+            setattr(self, name, obj)
 
     def __hash__(self) -> int:
         return hash(f"{self._name}{self.address}{self._project}")
@@ -892,6 +900,8 @@ class Contract(_DeployedContractBase):
             Contract owner. If set, transactions without a `from` field
             will be performed using this account.
         """
+        address_or_alias = address_or_alias.strip()
+
         if args or kwargs:
             warnings.warn(
                 "Initializing `Contract` in this manner is deprecated."
@@ -917,9 +927,9 @@ class Contract(_DeployedContractBase):
                 or not CONFIG.active_network.get("explorer")
             ):
                 if not address:
-                    raise ValueError(f"Unknown alias: {address_or_alias}")
+                    raise ValueError(f"Unknown alias: '{address_or_alias}'")
                 else:
-                    raise ValueError(f"Unknown contract address: {address}")
+                    raise ValueError(f"Unknown contract address: '{address}'")
             contract = self.from_explorer(address, owner=owner, silent=True)
             build, sources = contract._build, contract._sources
             address = contract.address
@@ -1099,10 +1109,10 @@ class Contract(_DeployedContractBase):
             )
             # always check for an EIP1822 proxy - https://eips.ethereum.org/EIPS/eip-1822
             implementation_eip1822 = web3.eth.getStorageAt(address, web3.keccak(text="PROXIABLE"))
-            if int(implementation_eip1967.hex(), 16):
-                as_proxy_for = _resolve_address(implementation_eip1967[12:])
-            elif int(implementation_eip1822.hex(), 16):
-                as_proxy_for = _resolve_address(implementation_eip1822[12:])
+            if len(implementation_eip1967) > 0 and int(implementation_eip1967.hex(), 16):
+                as_proxy_for = _resolve_address(implementation_eip1967[-20:])
+            elif len(implementation_eip1822) > 0 and int(implementation_eip1822.hex(), 16):
+                as_proxy_for = _resolve_address(implementation_eip1822[-20:])
             elif data["result"][0].get("Implementation"):
                 # for other proxy patterns, we only check if etherscan indicates
                 # the contract is a proxy. otherwise we could have a false positive
@@ -1830,8 +1840,19 @@ def _fetch_from_explorer(address: str, action: str, silent: bool) -> Dict:
     if address in _unverified_addresses:
         raise ValueError(f"Source for {address} has not been verified")
 
+    code = web3.eth.getCode(address).hex()[2:]
+    # EIP-1167: Minimal Proxy Contract
+    if code[:20] == "363d3d373d3d3d363d73" and code[60:] == "5af43d82803e903d91602b57fd5bf3":
+        address = _resolve_address(code[20:60])
+    # Vyper <0.2.9 `create_forwarder_to`
+    elif (
+        code[:30] == "366000600037611000600036600073"
+        and code[70:] == "5af4602c57600080fd5b6110006000f3"
+    ):
+        address = _resolve_address(code[30:70])
+
     params: Dict = {"module": "contract", "action": action, "address": address}
-    if "etherscan" in url:
+    if "etherscan" in url or "bscscan" in url:
         if os.getenv("ETHERSCAN_TOKEN"):
             params["apiKey"] = os.getenv("ETHERSCAN_TOKEN")
         elif not silent:
