@@ -120,7 +120,7 @@ class TransactionReceipt:
     contract_name = None
     fn_name = None
     gas_used = None
-    logs = None
+    logs: Optional[List] = None
     nonce = None
     sender = None
     txid: str
@@ -204,7 +204,10 @@ class TransactionReceipt:
     def events(self) -> Optional[EventDict]:
         if self._events is None:
             if self.status:
-                self._events = _decode_logs(self.logs)  # type: ignore
+                # relay contract map so we can decode ds-note logs
+                addrs = {log.address for log in self.logs} if self.logs else set()
+                contracts = {addr: state._find_contract(addr) for addr in addrs}
+                self._events = _decode_logs(self.logs, contracts=contracts)  # type: ignore
             else:
                 self._get_trace()
                 # get events from the trace - handled lazily so that other
@@ -536,8 +539,6 @@ class TransactionReceipt:
         )
         self.coverage_hash = sha1(base.encode()).hexdigest()
 
-        if self.status:
-            self._events = _decode_logs(receipt["logs"])
         if self.fn_name:
             state.TxHistory()._gas(self._full_name(), receipt["gasUsed"])
 
@@ -669,11 +670,16 @@ class TransactionReceipt:
 
                     # if this is the optimizer revert, find the actual source
                     if "optimizer_revert" in pc_map[step["pc"]]:
-                        idx = trace.index(step)
-                        while trace[idx]["op"] != "JUMPDEST":
-                            # look for the most recent jump
+                        idx = trace.index(step) - 1
+
+                        # look for the most recent jump
+                        while trace[idx + 1]["op"] != "JUMPDEST":
+                            if trace[idx]["source"] != step["source"]:
+                                # if we find another line with a differing source offset prior
+                                # to a JUMPDEST, the optimizer revert is also the actual revert
+                                idx = trace.index(step)
+                                break
                             idx -= 1
-                        idx -= 1
                         while not trace[idx]["source"]:
                             # now we're in a yul optimization, keep stepping back
                             # until we find a source offset
@@ -682,6 +688,7 @@ class TransactionReceipt:
                         step["source"] = trace[idx]["source"]
                         step = trace[idx]
 
+                    # breakpoint()
                     if "dev" in pc_map[step["pc"]]:
                         self._dev_revert_msg = pc_map[step["pc"]]["dev"]
                     else:
